/*  Glimmer - print-util.h
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _GLIMMER_PRINT_UTIL_H_
#define _GLIMMER_PRINT_UTIL_H_

#include "print.h"

int glimmer_print_show_iso8859_1 (GnomePrintContext *pc, char const *text);
gboolean glimmer_print_verify_fonts (void);

void glimmer_print_progress_start (PrintJobInfo *pji);
void glimmer_print_progress_tick (PrintJobInfo *pji, gint page);
void glimmer_print_progress_end (PrintJobInfo *pji);

#endif /* __GLIMMER_PRINT_UTIL_H__ */
